Actions, Resources, and Condition Keys for Amazon Pinpoint SMS and Voice Service - AWS Identity and Access Management
Description: Lists all of the available service-specific resources, actions, and condition keys that can be used in IAM policies to control access to Amazon Pinpoint SMS and Voice Service.
Keywords: IAM,AWS Identity and Access Management,IAM user,user,IAM group,group,IAM role,role,permission policy,trust policy,policy,access key,password

AWS Identity and Access Management
User Guide

The AWS Documentation website is getting a new look!
Try it now and let us know what you think. Switch to the new look >>
You can return to the original look by selecting English in the language selector above.

# Actions, Resources, and Condition Keys for Amazon Pinpoint SMS and Voice Service

Amazon Pinpoint SMS and Voice Service (service prefix: `sms-voice`) provides the following service-specific resources, actions, and condition context keys for use in IAM permission policies.

References:

- Learn how to configure this service.

- View a list of the API operations available for this service.

- Learn how to secure this service and its resources by using IAM permission policies.

Topics

- Actions Defined by Amazon Pinpoint SMS and Voice Service
- Resources Defined by Amazon Pinpoint SMS and Voice Service
- Condition Keys for Amazon Pinpoint SMS and Voice Service

## Actions Defined by Amazon Pinpoint SMS and Voice Service

You can specify the following actions in the `Action` element of an IAM policy statement. Use policies to grant permissions to perform an operation in AWS. When you use an action in a policy, you usually allow or deny access to the API operation or CLI command with the same name. However, in some cases, a single action controls access to more than one operation. Alternatively, some operations require several different actions.

The Resource column indicates whether each action supports resource-level permissions. If there is no value for this column, you must specify all resources ("*") in the `Resource` element of your policy statement. If the column includes a resource type, then you can specify an ARN of that type in a statement with that action. Required resources are indicated in the table with an asterisk (*). If you specify a resource-level permission ARN in a statement using this action, then it must be of this type. Some actions support multiple resource types. If the resource type is optional (not indicated as required), then you can choose to use one but not the other.

For details about the columns in the following table, see The Actions Table.

Actions | Description | Access Level | Resource Types (*required) | Condition Keys | Dependent Actions
--- | --- | --- | --- | --- | ---
CreateConfigurationSet | Create a new configuration set. After you create the configuration set, you can add one or more event destinations to it. | Write |  |  |
CreateConfigurationSetEventDestination | Create a new event destination in a configuration set. | Write |  |  | iam:PassRole
DeleteConfigurationSet | Deletes an existing configuration set. | Write |  |  |
DeleteConfigurationSetEventDestination | Deletes an event destination in a configuration set. | Write |  |  |
GetConfigurationSetEventDestinations | Obtain information about an event destination, including the types of events it reports, the Amazon Resource Name (ARN) of the destination, and the name of the event destination. | Read |  |  |
ListConfigurationSets | Return a list of configuration sets. This operation only returns the configuration sets that are associated with your account in the current AWS Region. | Read |  |  |
SendVoiceMessage | Create a new voice message and send it to a recipient's phone number. | Write |  |  |
UpdateConfigurationSetEventDestination | Update an event destination in a configuration set. An event destination is a location that you publish information about your voice calls to. For example, you can log an event to an Amazon CloudWatch destination when a call fails. | Write |  |  | iam:PassRole

## Resources Defined by Amazon Pinpoint SMS and Voice Service

Amazon Pinpoint SMS and Voice Service does not support specifying a resource ARN in the `Resource` element of an IAM policy statement. To allow access to Amazon Pinpoint SMS and Voice Service, specify `“Resource”: “*”` in your policy.

## Condition Keys for Amazon Pinpoint SMS and Voice Service

Pinpoint SMS Voice has no service-specific context keys that can be used in the `Condition` element of policy statements. For the list of the global context keys that are available to all services, see Available Keys for Conditions in the IAM Policy Reference.

On this page:

- Actions Defined by Amazon Pinpoint SMS and Voice Service
- Resources Defined by Amazon Pinpoint SMS and Voice Service
- Condition Keys for Amazon Pinpoint SMS and Voice Service

We use cookies to provide and improve our services. By using our site, you consent to cookies. Learn more